"use strict";
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CreateSigningPackage = void 0;
const core_1 = require("@oclif/core");
const command_1 = require("../../../../command");
const flags_1 = require("../../../../flags");
const longPrompt_1 = require("../../../../utils/longPrompt");
class CreateSigningPackage extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(CreateSigningPackage);
        let unsignedTransaction = flags.unsignedTransaction?.trim();
        if (!unsignedTransaction) {
            unsignedTransaction = await (0, longPrompt_1.longPrompt)('Enter the unsigned transaction', {
                required: true,
            });
        }
        let commitments = flags.commitment;
        if (!commitments) {
            const input = await (0, longPrompt_1.longPrompt)('Enter the signing commitments separated by commas', {
                required: true,
            });
            commitments = input.split(',');
        }
        commitments = commitments.map((s) => s.trim());
        const client = await this.sdk.connectRpc();
        const signingPackageResponse = await client.wallet.multisig.createSigningPackage({
            account: flags.account,
            unsignedTransaction,
            commitments,
        });
        this.log(`Signing Package for commitments from ${commitments.length} participants:\n`);
        this.log(signingPackageResponse.content.signingPackage);
    }
}
CreateSigningPackage.description = `Creates a signing package for a given transaction for a multisig account`;
CreateSigningPackage.hidden = true;
CreateSigningPackage.flags = {
    ...flags_1.RemoteFlags,
    account: core_1.Flags.string({
        char: 'f',
        description: 'The account to use when creating the signing package',
        required: false,
    }),
    unsignedTransaction: core_1.Flags.string({
        char: 'u',
        description: 'The unsigned transaction for which the signing share will be created',
    }),
    commitment: core_1.Flags.string({
        char: 'c',
        description: 'The signing commitments from participants to be used for creating the signing package',
        multiple: true,
    }),
};
exports.CreateSigningPackage = CreateSigningPackage;
//# sourceMappingURL=aggregate.js.map