"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CreateSignatureShareCommand = void 0;
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
const sdk_1 = require("@ironfish/sdk");
const core_1 = require("@oclif/core");
const command_1 = require("../../../../command");
const flags_1 = require("../../../../flags");
const longPrompt_1 = require("../../../../utils/longPrompt");
const transaction_1 = require("../../../../utils/transaction");
class CreateSignatureShareCommand extends command_1.IronfishCommand {
    async start() {
        const { flags } = await this.parse(CreateSignatureShareCommand);
        let signingPackage = flags.signingPackage?.trim();
        if (!signingPackage) {
            signingPackage = await (0, longPrompt_1.longPrompt)('Enter the signing package');
        }
        const client = await this.sdk.connectRpc();
        const unsignedTransaction = sdk_1.UnsignedTransaction.fromSigningPackage(signingPackage);
        await (0, transaction_1.renderUnsignedTransactionDetails)(client, unsignedTransaction, flags.account, this.logger);
        if (!flags.confirm) {
            const confirmed = await core_1.CliUx.ux.confirm('Confirm new signature share creation (Y/N)');
            if (!confirmed) {
                this.error('Creating signature share aborted');
            }
        }
        const signatureShareResponse = await client.wallet.multisig.createSignatureShare({
            account: flags.account,
            signingPackage,
        });
        this.log();
        this.log('Signature Share:');
        this.log(signatureShareResponse.content.signatureShare);
    }
}
CreateSignatureShareCommand.description = `Creates a signature share for a participant for a given transaction`;
CreateSignatureShareCommand.hidden = true;
CreateSignatureShareCommand.flags = {
    ...flags_1.RemoteFlags,
    account: core_1.Flags.string({
        char: 'f',
        description: 'The account from which the signature share will be created',
        required: false,
    }),
    signingPackage: core_1.Flags.string({
        char: 's',
        description: 'The signing package for which the signature share will be created',
        required: false,
    }),
    confirm: core_1.Flags.boolean({
        default: false,
        description: 'Confirm creating signature share without confirming',
    }),
};
exports.CreateSignatureShareCommand = CreateSignatureShareCommand;
//# sourceMappingURL=create.js.map